@@ -44,6 +44,11 @@ def init_project():
         npmrc = Path.home().joinpath(".npmrc")
         npmrc.write_text(f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n")
 
+    if settings.PREFECT_API_KEY:
+        bash(f"prefect cloud login -k {settings.PREFECT_API_KEY}")
+        bash("prefect config set PREFECT_API_URL=\"http://127.0.0.1:4200/api\"")
+        # bash("prefect server start")
+
     # if command_exists("cursor"):
     #     bash("cursor --version")
     #     bash("cursor --install-extension ms-python.vscode-pylance")
@@ -127,7 +132,8 @@ def docker_build_base():
 
 
 async def run_deploy():
-    await dp_vercel_mtmaiadmin()
+    # await dp_vercel_mtmaiadmin()
+    await dp_vercel_mtmaifront()
     await run_tmpbo_instance1()
     logger.info("✅ tembo io pushed")
     hf_trans1_commit()
@@ -180,8 +186,9 @@ def release_py():
 
 def release_npm():
     npm_packages = [
-        "apps/mtmaiweb",
-        "apps/mtmaiadmin",
+        # "apps/mtmaiweb",
+        # "apps/mtmaiadmin",
+        "apps/mtmaifront",
         "packages/mtmeditor",
         "packages/mtmscreentocode",
         "packages/mtxuilib",
@@ -237,3 +244,18 @@ async def dp_vercel_mtmaiadmin():
         build_local=False,
     )
     git_commit_push()
+
+
+async def dp_vercel_mtmaifront():
+    logger.info("🚀 正在部署到 vercel")
+    from mtmlib import vercel
+
+    vercel.deploy_vercel(
+        project_dir="apps/mtmaifront",
+        is_cfpage=False,
+        project_name="mtmaifront",
+        vercel_token=settings.vercel_token,
+        deploy_to_vercel=True,
+        build_local=False,
+    )
+    git_commit_push()
