@@ -2,19 +2,14 @@ import logging
 from pathlib import Path
 
 from fastapi import APIRouter
+from mtmlib.mtutils import bash
 
 from mtmai.core.config import settings
-from mtmai.mtlibs.process_helper import bash
 
 router = APIRouter()
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
 
 
-# @router.get(
-#     "/hf_space_clone",
-#     dependencies=[Depends(get_current_active_superuser)],
-#     status_code=201,
-# )
 def hf_trans1_clone():
     target_dir = (
         Path(settings.storage_dir)
