@@ -1,8 +1,9 @@
 from fastapi.testclient import TestClient
 from sqlmodel import Session
+from sqlmodel.ext.asyncio.session import AsyncSession
 
 from mtmai.core.config import settings
-from mtmai.curd import crud
+from mtmai.crud import crud
 from mtmai.models.models import User, UserCreate, UserUpdate
 from mtmai.tests.utils.utils import random_email, random_lower_string
 
@@ -27,8 +28,8 @@ def create_random_user(db: Session) -> User:
     return user
 
 
-def authentication_token_from_email(
-    *, client: TestClient, email: str, db: Session
+async def authentication_token_from_email(
+    *, client: TestClient, email: str, db: AsyncSession
 ) -> dict[str, str]:
     """
     Return a valid token for the user with given email.
@@ -36,14 +37,14 @@ def authentication_token_from_email(
     If the user doesn't exist it is created first.
     """
     password = random_lower_string()
-    user = crud.get_user_by_email(session=db, email=email)
+    user = await crud.get_user_by_email(session=db, email=email)
     if not user:
         user_in_create = UserCreate(email=email, password=password)
-        user = crud.create_user(session=db, user_create=user_in_create)
+        user = await crud.create_user(session=db, user_create=user_in_create)
     else:
         user_in_update = UserUpdate(password=password)
         if not user.id:
             raise Exception("User id not set")
-        user = crud.update_user(session=db, db_user=user, user_in=user_in_update)
+        user = await crud.update_user(session=db, db_user=user, user_in=user_in_update)
 
     return user_authentication_headers(client=client, email=email, password=password)
